@@ -1,18 +1,12 @@
 import datetime
-from python_helper import DateTimeHelper
+from python_helper import DateTimeHelper, ObjectHelper
 
 def now():
     return datetime.datetime.utcnow()
 
-def timestamp():
-    return datetime.datetime.timestamp()
-
 def ofTimestamp(t):
     return datetime.datetime.utcfromtimestamp(t)
-
-def ofPlainTimestamp(t):
-    return datetime.datetime.fromtimestamp(t)
-
+    
 def plusMinutes(givenDateTime, minutes=None, deltaInMinutes=None) :
     if ObjectHelper.isNotNone(minutes) :
         deltaInMinutes = DateTimeHelper.timeDelta(seconds=minutes*60)
